##  Privacy Settings of Subscription Visibility
Admins can manage how subscription information is displayed to users in the filter panel of the inventory, reports, and diagrams by adjusting the privacy settings. To configure these settings, follow these steps:
  1. In the administration area, select General.
  2. Under Data Privacy, choose between two levels of privacy:
     * Relaxed Mode: Users can see other subscribers in the subscription filter and use this information to filter fact sheets.
     * Normal Mode: Users cannot see other subscribers in the filter panel.
  3. Click Save to apply the change.


This setting does not impact users' ability to view subscribers of a particular fact sheet in the subscriptions tab of the fact sheet.
![Privacy Modes of Subscribers Visibility](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274bd5c87a441014ac74bd1a35b8fa61_LowRes.png)
Privacy Modes of Subscribers Visibility
